==> baserow_open_api_client-0.0.1a0.tar.gz: baserow_open_api_client-0.0.1a0/baserow_open_api_client/api/user/create_user.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.create_user_response_200 import CreateUserResponse200
from ...models.create_user_response_400 import CreateUserResponse400
from ...models.create_user_response_404 import CreateUserResponse404
from ...models.register import Register
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: Register,
) -> Dict[str, Any]:
    url = "{}/api/user/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    result = {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }

    if hasattr(client, "auth"):
        result["auth"] = client.auth

    return result


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CreateUserResponse200.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = CreateUserResponse400.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = CreateUserResponse404.from_dict(response.json())

        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: Register,
) -> Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    json_body: Register,
) -> Optional[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: Register,
) -> Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    json_body: Register,
) -> Optional[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> baserow_open_api_client-0.0.4.tar.gz: baserow_open_api_client-0.0.4/baserow_open_api_client/api/user/create_user.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.create_user_response_200 import CreateUserResponse200
from ...models.create_user_response_400 import CreateUserResponse400
from ...models.create_user_response_404 import CreateUserResponse404
from ...models.register import Register
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: Register,
) -> Dict[str, Any]:
    url = "{}/api/user/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    result = {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }

    if hasattr(client, "auth"):
        result["auth"] = client.auth

    return result


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CreateUserResponse200.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = CreateUserResponse400.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = CreateUserResponse404.from_dict(response.json())

        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *, client: Client, json_body: Register, httpx_client=None
) -> Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = (httpx_client or httpx).request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    json_body: Register,
) -> Optional[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: Register,
) -> Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    json_body: Register,
) -> Optional[Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]]:
    """Creates a new user based on the provided values. If desired an authentication JWT can be generated
    right away. After creating an account the initial workspace containing a database is created.

    Args:
        json_body (Register):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CreateUserResponse200, CreateUserResponse400, CreateUserResponse404]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
